(function ($, Drupal, drupalSettings) {
  'use strict';

  var direction;
  var seedsToobarLogo;

  var adjustToolbarWidth = function () {
    $('#toolbar-administration .seeds-toolbar-background').css('min-width', getToolbarWidth(true));
    $('body').css('margin-' + direction, getToolbarWidth());
    if ($('.toolbar-tray.shown').length) {
      $(seedsToobarLogo).width(getToolbarMenuWidth(true));
      $(seedsToobarLogo).css(direction, $('#toolbar-bar').width());
    }
  }

  var openMenu = function (menu) {
    // If the tab that was click doesn't have a menu/tray, assume that the toolbar was closed.
    if (menu.length) {
      closeMenu('.toolbar-tray.shown', false);
      $('body').addClass('seeds-toolbar-open');
    } else {
      closeMenu('.toolbar-tray.shown');
    }
    $(menu).attr('style', `${direction}: ${$('#toolbar-bar').width()}px !important`).addClass('shown');
    $('#toolbar-administration').addClass('toolbar-open');
    adjustToolbarWidth();
  }

  var closeMenu = function (menu, totallyClosed = true) {
    if (totallyClosed) {
      $('body').removeClass('seeds-toolbar-open');
    }
    $('.seeds-toolbar-background').removeClass('no-transition');
    if ($('.toolbar-tray.shown').length) {
      $(seedsToobarLogo).css(direction, -getToolbarMenuWidth(true));
    }
    $(menu).attr('style', `${direction}: ${-$(menu).width()}px !important`).removeClass('shown');
    $('#toolbar-administration').removeClass('toolbar-open');
    adjustToolbarWidth();
  }

  var getToolbarMenuWidth = function (unfiltered) {
    return isMobile() && !unfiltered ? 0 : ($('.toolbar-tray.shown').width() || 0);
  }

  var getToolbarWidth = function (unfiltered = false) {
    return getToolbarMenuWidth(unfiltered) + $('#toolbar-bar').width();
  }

  var isMobile = function () {
    return $('.mobile-indicator').is(':hidden');
  }

  Drupal.behaviors.seedsToolbar = {
    attach: function (context, settings) {
      if (context == document) {
        direction = $('html').attr('dir') == 'rtl' ? 'right' : 'left';
        seedsToobarLogo = $('.toolbar-menu-administration>ul>li').first();
        // Initialize width on toolbar.
        if (!drupalSettings.seeds_toolbar.compact && !isMobile()) {
          var tray = $('#toolbar-item-administration').attr('data-toolbar-tray');
          openMenu($('#' + tray));
        }
        adjustToolbarWidth();

        // Remove toolbar core classes as a fallback. ( Should be removed from backend, but because the config needs to be exported and the cache needs to be cleared first. )
        $('body').removeClass('toolbar-horizontal', 'toolbar-tray-open');

        // Open child menu'.
        $('.toolbar-menu-administration>ul li>a>.seeds-expand-item').click(function (event) {
          var parentItem = $(this).parent().parent();
          // Remove transition from seeds-background to prevent out-of-sync behaviors.
          $('.seeds-toolbar-background').addClass('no-transition');
          // Close other items if the first level icons were clicked.
          if (parentItem.parent().parent().hasClass('toolbar-menu-administration')) {
            $('.toolbar-menu-administration>ul>li').not(parentItem).removeClass('mobile-open');
          }
          if (isMobile()) {
            event.preventDefault();
            parentItem.toggleClass('mobile-open');
            adjustToolbarWidth();
          }
        });

        // Toolbar tabs click
        $('.toolbar-tab>button,.toolbar-tab>a:not(.toolbar-icon-escape-admin)').click((e) => {

          if ($(e.target).hasClass('trigger')) {
            e.preventDefault();
          }
          var tray = $(e.target).nextAll('.toolbar-tray');
          if ($(tray).hasClass('shown')) {
            closeMenu(tray);
          } else {
            openMenu(tray);
          }
        });

        // Clicking on responsive preview item closes the menu
        $('#responsive-preview-toolbar-tab ul button').click(() => {
          closeMenu('.toolbar-tray.shown');
        });

        $('.dialog-off-canvas-main-canvas').on('touchstart', function (event) {
          if (isMobile()) {
            closeMenu('.toolbar-tray.shown');
          }
        });
      }
    }
  };
})(jQuery, Drupal, drupalSettings);
