<?php

namespace Drupal\seeds_toolbar;

use Drupal\Core\Link;
use Drupal\Core\Url;

class SeedsManager {

  protected $menuLinkPluginManager;
  protected $menuTree;
  protected $languageManager;
  protected $currentUser;
  protected $entityTypeManager;
  protected $blockContentPermissions;

  public function __construct($menu_link_plugin_manager, $menu_tree, $language_manager, $current_user, $entity_type_manager, $module_handler) {
    $this->menuLinkPluginManager = $menu_link_plugin_manager;
    $this->menuTree = $menu_tree;
    $this->languageManager = $language_manager;
    $this->currentUser = $current_user;
    $this->entityTypeManager = $entity_type_manager;
    $this->blockContentPermissions = $module_handler->moduleExists('block_content_permissions');
  }

  public function buildMenu($entity_type, $route) {
    $entities = $this->entityTypeManager->getStorage($entity_type)->loadMultiple();
    $items = [];
    foreach ($entities as $entity) {
      $id = $entity->id();
      $url = Url::fromRoute($route, [$entity_type => $id]);
      // Block content are a special case, so we want to handle it.
      if ($entity_type == 'block_content_type') {
        $access = $this->handleBlockPermission($entity);
      } else {
        $access = $this->userHasAccess($url);
      }
      if ($access) {
        $items[$id] = Link::fromTextAndUrl($entity->label(), $url);

      }
    }
    if (empty($items)) {
      return [];
    } else {
      return [
        '#menu_name' => $entity_type . '-add-menu',
        '#items' => $items,
        '#theme' => 'seeds_add_menu',
      ];
    }
  }

  private function userHasAccess($url) {
    $current_user = \Drupal::currentUser();
    return $url->access($current_user);
  }

  private function handleBlockPermission($block_type) {
    if ($this->blockContentPermissions) {
      $type_id = $block_type->id();
      return $this->currentUser->hasPermission("create $type_id block content");
    } else {
      return $this->currentUser->hasPermission("administer blocks");
    }
  }

  public function getDirection() {
    $dir = $this->languageManager->getCurrentLanguage()->getDirection();
    return ($dir == 'ltr') ? 'left' : 'right';
  }

  public static function sortTabs(array $items, array $first_tabs) {
    $counter = 1;
    foreach ($items as $id => &$item) {
      if (in_array($id, $first_tabs)) {
        $item['#weight'] = array_search($id, $first_tabs);
      } else if ($id == 'admin_toolbar_tools') {
        // Always put admin_toolbar_tools at the last tab.
        $item['#weight'] = 1000;
      } else {
        $item['#weight'] = count($first_tabs) + $counter;
      }
      $counter++;
    }
    return $items;
  }
}
